==> tuia-advert-center-api-2.4.44-sources.jar: cn/com/duiba/tuia/core/api/dto/AuditRecordsFilterItemsDto.java <==
package cn.com.duiba.tuia.core.api.dto;


import java.util.List;

public class AuditRecordsFilterItemsDto {

    // "开始时间"
    private String startDate;

    // "结束时间"
    private String endDate;

    //广告计划id
    private Long advertId;

    private String advertName;

    //广告主ID列表
    private List<Long> advertiseIds;

    // "广告主id"
    private Long advertiseId;

    // "广告主名称"
    private String advertiseName;

    // 代理商名称
    private String agentName;

    // "ae名称"
    private String aeName;

    // 销售名称
    private String sellName;

    // "审核状态"
    private String auditStatus;

    // "行业"
    private String industry;

    //一级代理商名称
    private String levelOneAgentName;

    // 素材id
    private Long materialId;
    // 资质资源id
    private Long qualificationId;
    //资质资源min
    private String qualificationName;
    /** 资质内容 */
    private List<String> qualificationContentList;
    // 排除ID
    private Long excludedId;

    private Integer rowStart = 0;

    /**
     * 当前页.
     */
    private Integer currentPage = 1;

    /**
     * 每页记录数，默认为50， 为-1时代表查询所有.
     */
    private Integer pageSize = 50;

    /**
     * 排序字段.
     */
    private String sort;

    /**
     * 排序方式：(升序:asc,降序：desc)默认降序.
     */
    private String order = "desc";

    public String getQualificationName() {
        return qualificationName;
    }

    public void setQualificationName(String qualificationName) {
        this.qualificationName = qualificationName;
    }

    public List<String> getQualificationContentList() {
        return qualificationContentList;
    }

    public void setQualificationContentList(List<String> qualificationContentList) {
        this.qualificationContentList = qualificationContentList;
    }

    public String getStartDate() {
        return startDate;
    }

    public void setStartDate(String startDate) {
        this.startDate = startDate;
    }

    public String getEndDate() {
        return endDate;
    }

    public void setEndDate(String endDate) {
        this.endDate = endDate;
    }

    public Long getAdvertId() {
        return advertId;
    }

    public void setAdvertId(Long advertId) {
        this.advertId = advertId;
    }

    public List<Long> getAdvertiseIds() {
        return advertiseIds;
    }

    public void setAdvertiseIds(List<Long> advertiseIds) {
        this.advertiseIds = advertiseIds;
    }

    public Long getAdvertiseId() {
        return advertiseId;
    }

    public void setAdvertiseId(Long advertiseId) {
        this.advertiseId = advertiseId;
    }

    public String getAdvertiseName() {
        return advertiseName;
    }

    public void setAdvertiseName(String advertiseName) {
        this.advertiseName = advertiseName;
    }

    public String getAgentName() {
        return agentName;
    }

    public void setAgentName(String agentName) {
        this.agentName = agentName;
    }

    public String getSellName() {
        return sellName;
    }

    public void setSellName(String sellName) {
        this.sellName = sellName;
    }

    public String getAeName() {
        return aeName;
    }

    public void setAeName(String aeName) {
        this.aeName = aeName;
    }

    public String getAuditStatus() {
        return auditStatus;
    }

    public void setAuditStatus(String auditStatus) {
        this.auditStatus = auditStatus;
    }

    public String getIndustry() {
        return industry;
    }

    public void setIndustry(String industry) {
        this.industry = industry;
    }

    public String getLevelOneAgentName() {
        return levelOneAgentName;
    }

    public void setLevelOneAgentName(String levelOneAgentName) {
        this.levelOneAgentName = levelOneAgentName;
    }

    public Integer getRowStart() {
        return rowStart;
    }

    public void setRowStart(Integer rowStart) {
        this.rowStart = rowStart;
    }

    public Integer getCurrentPage() {
        return currentPage;
    }

    public void setCurrentPage(Integer currentPage) {
        this.currentPage = currentPage;
    }

    public Integer getPageSize() {
        return pageSize;
    }

    public void setPageSize(Integer pageSize) {
        this.pageSize = pageSize;
    }

    public String getSort() {
        return sort;
    }

    public void setSort(String sort) {
        this.sort = sort;
    }

    public String getOrder() {
        return order;
    }

    public void setOrder(String order) {
        this.order = order;
    }

    public String getAdvertName() {
        return advertName;
    }

    public void setAdvertName(String advertName) {
        this.advertName = advertName;
    }

    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }

    public Long getQualificationId() {
        return qualificationId;
    }

    public void setQualificationId(Long qualificationId) {
        this.qualificationId = qualificationId;
    }

    public Long getExcludedId() {
        return excludedId;
    }

    public void setExcludedId(Long excludedId) {
        this.excludedId = excludedId;
    }
}

==> tuia-advert-center-api-2.4.70-sources.jar: cn/com/duiba/tuia/core/api/dto/AuditRecordsFilterItemsDto.java <==
package cn.com.duiba.tuia.core.api.dto;


import java.util.List;

public class AuditRecordsFilterItemsDto {

    // "开始时间"
    private String startDate;

    // "结束时间"
    private String endDate;

    //广告计划id
    private Long advertId;

    private String advertName;

    //广告主ID列表
    private List<Long> advertiseIds;

    // "广告主id"
    private Long advertiseId;

    // "广告主名称"
    private String advertiseName;

    // 代理商名称
    private String agentName;

    // "ae名称"
    private String aeName;

    // 销售名称
    private String sellName;

    // "审核状态"
    private String auditStatus;

    // "行业"
    private String industry;

    //一级代理商名称
    private String levelOneAgentName;

    // 素材id
    private Long materialId;
    // 资质资源id
    private Long qualificationId;
    //资质资源min
    private String qualificationName;
    /** 资质内容 */
    private List<String> qualificationContentList;
    // 排除ID
    private Long excludedId;

    /**
     * 落地页ID
     */
    private Long landPageId;

    /**
     * 落地页类型：0:测试落地页；1:新媒体落地页；2:配置落地页；4:素材绑定落地页
     */
    private Integer urlType;

    private Integer rowStart = 0;

    /**
     * 当前页.
     */
    private Integer currentPage = 1;

    /**
     * 每页记录数，默认为50， 为-1时代表查询所有.
     */
    private Integer pageSize = 50;

    /**
     * 排序字段.
     */
    private String sort;

    /**
     * 排序方式：(升序:asc,降序：desc)默认降序.
     */
    private String order = "desc";

    public String getQualificationName() {
        return qualificationName;
    }

    public void setQualificationName(String qualificationName) {
        this.qualificationName = qualificationName;
    }

    public List<String> getQualificationContentList() {
        return qualificationContentList;
    }

    public void setQualificationContentList(List<String> qualificationContentList) {
        this.qualificationContentList = qualificationContentList;
    }

    public String getStartDate() {
        return startDate;
    }

    public void setStartDate(String startDate) {
        this.startDate = startDate;
    }

    public String getEndDate() {
        return endDate;
    }

    public void setEndDate(String endDate) {
        this.endDate = endDate;
    }

    public Long getAdvertId() {
        return advertId;
    }

    public void setAdvertId(Long advertId) {
        this.advertId = advertId;
    }

    public List<Long> getAdvertiseIds() {
        return advertiseIds;
    }

    public void setAdvertiseIds(List<Long> advertiseIds) {
        this.advertiseIds = advertiseIds;
    }

    public Long getAdvertiseId() {
        return advertiseId;
    }

    public void setAdvertiseId(Long advertiseId) {
        this.advertiseId = advertiseId;
    }

    public String getAdvertiseName() {
        return advertiseName;
    }

    public void setAdvertiseName(String advertiseName) {
        this.advertiseName = advertiseName;
    }

    public String getAgentName() {
        return agentName;
    }

    public void setAgentName(String agentName) {
        this.agentName = agentName;
    }

    public String getSellName() {
        return sellName;
    }

    public void setSellName(String sellName) {
        this.sellName = sellName;
    }

    public String getAeName() {
        return aeName;
    }

    public void setAeName(String aeName) {
        this.aeName = aeName;
    }

    public String getAuditStatus() {
        return auditStatus;
    }

    public void setAuditStatus(String auditStatus) {
        this.auditStatus = auditStatus;
    }

    public String getIndustry() {
        return industry;
    }

    public void setIndustry(String industry) {
        this.industry = industry;
    }

    public String getLevelOneAgentName() {
        return levelOneAgentName;
    }

    public void setLevelOneAgentName(String levelOneAgentName) {
        this.levelOneAgentName = levelOneAgentName;
    }

    public Integer getRowStart() {
        return rowStart;
    }

    public void setRowStart(Integer rowStart) {
        this.rowStart = rowStart;
    }

    public Integer getCurrentPage() {
        return currentPage;
    }

    public void setCurrentPage(Integer currentPage) {
        this.currentPage = currentPage;
    }

    public Integer getPageSize() {
        return pageSize;
    }

    public void setPageSize(Integer pageSize) {
        this.pageSize = pageSize;
    }

    public String getSort() {
        return sort;
    }

    public void setSort(String sort) {
        this.sort = sort;
    }

    public String getOrder() {
        return order;
    }

    public void setOrder(String order) {
        this.order = order;
    }

    public String getAdvertName() {
        return advertName;
    }

    public void setAdvertName(String advertName) {
        this.advertName = advertName;
    }

    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }

    public Long getQualificationId() {
        return qualificationId;
    }

    public void setQualificationId(Long qualificationId) {
        this.qualificationId = qualificationId;
    }

    public Long getExcludedId() {
        return excludedId;
    }

    public void setExcludedId(Long excludedId) {
        this.excludedId = excludedId;
    }

    public Long getLandPageId() {
        return landPageId;
    }

    public void setLandPageId(Long landPageId) {
        this.landPageId = landPageId;
    }

    public Integer getUrlType() {
        return urlType;
    }

    public void setUrlType(Integer urlType) {
        this.urlType = urlType;
    }
}
